/* Generated at libc build time from kernel syscall list.  */
#define SYS_write __NR_write
#define SYS_setrlimit __NR_setrlimit
#define SYS_osf_old_sigsetmask __NR_osf_old_sigsetmask
#define SYS_getdents __NR_getdents
#define SYS_umount __NR_umount
#define SYS_munlock __NR_munlock
#define SYS_delete_module __NR_delete_module
#define SYS_fstat __NR_fstat
#define SYS_getpgid __NR_getpgid
#define SYS_madvise __NR_madvise
#define SYS_osf_swapon __NR_osf_swapon
#define SYS_setfsgid __NR_setfsgid
#define SYS_osf_msfs_syscall __NR_osf_msfs_syscall
#define SYS_osf_sigprocmask __NR_osf_sigprocmask
#define SYS_chroot __NR_chroot
#define SYS_osf_execve __NR_osf_execve
#define SYS_times __NR_times
#define SYS_osf_pathconf __NR_osf_pathconf
#define SYS_osf_reboot __NR_osf_reboot
#define SYS_setpgid __NR_setpgid
#define SYS_getpgrp __NR_getpgrp
#define SYS_getsockopt __NR_getsockopt
#define SYS_osf_setsysinfo __NR_osf_setsysinfo
#define SYS_osf_alt_setsid __NR_osf_alt_setsid
#define SYS_query_module __NR_query_module
#define SYS_writev __NR_writev
#define SYS_rename __NR_rename
#define SYS_truncate __NR_truncate
#define SYS_setpgrp __NR_setpgrp
#define SYS_sigreturn __NR_sigreturn
#define SYS_gethostname __NR_gethostname
#define SYS_fsync __NR_fsync
#define SYS_osf_shmat __NR_osf_shmat
#define SYS_lstat __NR_lstat
#define SYS_dup2 __NR_dup2
#define SYS_clone __NR_clone
#define SYS_sethae __NR_sethae
#define SYS_osf_usleep_thread __NR_osf_usleep_thread
#define SYS_close __NR_close
#define SYS_setgid __NR_setgid
#define SYS_osf_kloadcall __NR_osf_kloadcall
#define SYS_osf_nfssvc __NR_osf_nfssvc
#define SYS_bdflush __NR_bdflush
#define SYS_osf_pid_unblock __NR_osf_pid_unblock
#define SYS_osf_kmodcall __NR_osf_kmodcall
#define SYS_statfs __NR_statfs
#define SYS_mount __NR_mount
#define SYS_osf_getdirentries __NR_osf_getdirentries
#define SYS_osf_old_sigblock __NR_osf_old_sigblock
#define SYS_idle __NR_idle
#define SYS_sigaction __NR_sigaction
#define SYS_osf_sigwaitprim __NR_osf_sigwaitprim
#define SYS_wait4 __NR_wait4
#define SYS_fork __NR_fork
#define SYS_osf_fpathconf __NR_osf_fpathconf
#define SYS_setfsuid __NR_setfsuid
#define SYS_osf_swapctl __NR_osf_swapctl
#define SYS_osf_sigaltstack __NR_osf_sigaltstack
#define SYS_settimeofday __NR_settimeofday
#define SYS_osf_gethostid __NR_osf_gethostid
#define SYS_osf_chflags __NR_osf_chflags
#define SYS_osf_subsys_info __NR_osf_subsys_info
#define SYS_setsockopt __NR_setsockopt
#define SYS_afs_syscall __NR_afs_syscall
#define SYS_osf_old_sigvec __NR_osf_old_sigvec
#define SYS_osf_ngetpeername __NR_osf_ngetpeername
#define SYS_exit __NR_exit
#define SYS_sysinfo __NR_sysinfo
#define SYS_osf_fchflags __NR_osf_fchflags
#define SYS_getsockname __NR_getsockname
#define SYS_socket __NR_socket
#define SYS_symlink __NR_symlink
#define SYS_osf_nrecvfrom __NR_osf_nrecvfrom
#define SYS_ioctl __NR_ioctl
#define SYS_ftruncate __NR_ftruncate
#define SYS_sched_getparam __NR_sched_getparam
#define SYS_setresuid __NR_setresuid
#define SYS_osf_memcntl __NR_osf_memcntl
#define SYS_sched_rr_get_interval __NR_sched_rr_get_interval
#define SYS_osf_fstatfs __NR_osf_fstatfs
#define SYS_osf_audcntl __NR_osf_audcntl
#define SYS_fcntl __NR_fcntl
#define SYS_osf_msleep __NR_osf_msleep
#define SYS_osf_pid_block __NR_osf_pid_block
#define SYS_setsid __NR_setsid
#define SYS_mprotect __NR_mprotect
#define SYS_osf_old_getpgrp __NR_osf_old_getpgrp
#define SYS_osf_getaddressconf __NR_osf_getaddressconf
#define SYS_osf_oldquota __NR_osf_oldquota
#define SYS_osf_syscall __NR_osf_syscall
#define SYS_setuid __NR_setuid
#define SYS_socketpair __NR_socketpair
#define SYS_umask __NR_umask
#define SYS_osf_afs_syscall __NR_osf_afs_syscall
#define SYS_osf_ntp_adjtime __NR_osf_ntp_adjtime
#define SYS_osf_waitid __NR_osf_waitid
#define SYS_kill __NR_kill
#define SYS_osf_nrecvmsg __NR_osf_nrecvmsg
#define SYS_osf_naccept __NR_osf_naccept
#define SYS_nanosleep __NR_nanosleep
#define SYS_uname __NR_uname
#define SYS_getitimer __NR_getitimer
#define SYS_shmctl __NR_shmctl
#define SYS_osf_getdomainname __NR_osf_getdomainname
#define SYS_readv __NR_readv
#define SYS_osf_umount __NR_osf_umount
#define SYS_osf_mincore __NR_osf_mincore
#define SYS_shmget __NR_shmget
#define SYS_osf_security __NR_osf_security
#define SYS_getpriority __NR_getpriority
#define SYS_msync __NR_msync
#define SYS_link __NR_link
#define SYS_sched_setparam __NR_sched_setparam
#define SYS_osf_ntp_gettime __NR_osf_ntp_gettime
#define SYS_getxgid __NR_getxgid
#define SYS_osf_mvalid __NR_osf_mvalid
#define SYS_recvmsg __NR_recvmsg
#define SYS_getrusage __NR_getrusage
#define SYS_osf_fuser __NR_osf_fuser
#define SYS_osf_asynch_daemon __NR_osf_asynch_daemon
#define SYS_recvfrom __NR_recvfrom
#define SYS_osf_sigsendset __NR_osf_sigsendset
#define SYS_sched_yield __NR_sched_yield
#define SYS_connect __NR_connect
#define SYS_osf_nsendmsg __NR_osf_nsendmsg
#define SYS_osf_profil __NR_osf_profil
#define SYS_mmap __NR_mmap
#define SYS_get_kernel_syms __NR_get_kernel_syms
#define SYS_setgroups __NR_setgroups
#define SYS_munmap __NR_munmap
#define SYS_osf_getfsstat __NR_osf_getfsstat
#define SYS_quotactl __NR_quotactl
#define SYS_getrlimit __NR_getrlimit
#define SYS_osf_mount __NR_osf_mount
#define SYS_osf_mwakeup __NR_osf_mwakeup
#define SYS_brk __NR_brk
#define SYS_sched_getscheduler __NR_sched_getscheduler
#define SYS_personality __NR_personality
#define SYS_vhangup __NR_vhangup
#define SYS_getxpid __NR_getxpid
#define SYS_mremap __NR_mremap
#define SYS_osf_statfs __NR_osf_statfs
#define SYS_getpagesize __NR_getpagesize
#define SYS_ptrace __NR_ptrace
#define SYS_sendmsg __NR_sendmsg
#define SYS_dup __NR_dup
#define SYS_getsid __NR_getsid
#define SYS_uselib __NR_uselib
#define SYS_shutdown __NR_shutdown
#define SYS_osf_old_killpg __NR_osf_old_killpg
#define SYS_osf_old_vadvise __NR_osf_old_vadvise
#define SYS_osf_audgen __NR_osf_audgen
#define SYS_init_module __NR_init_module
#define SYS_getxuid __NR_getxuid
#define SYS_osf_alt_sigpending __NR_osf_alt_sigpending
#define SYS_osf_sigstack __NR_osf_sigstack
#define SYS_osf_uadmin __NR_osf_uadmin
#define SYS_pipe __NR_pipe
#define SYS_read __NR_read
#define SYS_osf_set_speculative __NR_osf_set_speculative
#define SYS_open __NR_open
#define SYS_setdomainname __NR_setdomainname
#define SYS_setregid __NR_setregid
#define SYS_recv __NR_recv
#define SYS_osf_lchown __NR_osf_lchown
#define SYS_getdtablesize __NR_getdtablesize
#define SYS_osf_fdatasync __NR_osf_fdatasync
#define SYS_nfsctl __NR_nfsctl
#define SYS_osf_proplist_syscall __NR_osf_proplist_syscall
#define SYS_osf_old_sigreturn __NR_osf_old_sigreturn
#define SYS_poll __NR_poll
#define SYS_osf_vfork __NR_osf_vfork
#define SYS_flock __NR_flock
#define SYS_osf_adjtime __NR_osf_adjtime
#define SYS_sigsuspend __NR_sigsuspend
#define SYS_send __NR_send
#define SYS_sysfs __NR_sysfs
#define SYS_osf_sbrk __NR_osf_sbrk
#define SYS_sethostname __NR_sethostname
#define SYS_osf_old_vtrace __NR_osf_old_vtrace
#define SYS_swapon __NR_swapon
#define SYS_osf_signal __NR_osf_signal
#define SYS_create_module __NR_create_module
#define SYS_execve __NR_execve
#define SYS_osf_old_sigaction __NR_osf_old_sigaction
#define SYS_osf_old_fstat __NR_osf_old_fstat
#define SYS_osf_sysinfo __NR_osf_sysinfo
#define SYS_reboot __NR_reboot
#define SYS_osf_old_open __NR_osf_old_open
#define SYS_semop __NR_semop
#define SYS_osf_ngetsockname __NR_osf_ngetsockname
#define SYS_msgctl __NR_msgctl
#define SYS_fchdir __NR_fchdir
#define SYS_getresuid __NR_getresuid
#define SYS_msgget __NR_msgget
#define SYS_osf_utc_adjtime __NR_osf_utc_adjtime
#define SYS_osf_sethostid __NR_osf_sethostid
#define SYS_setreuid __NR_setreuid
#define SYS_getpeername __NR_getpeername
#define SYS_select __NR_select
#define SYS_ustat __NR_ustat
#define SYS_osf_plock __NR_osf_plock
#define SYS_mkdir __NR_mkdir
#define SYS_rmdir __NR_rmdir
#define SYS_adjtimex __NR_adjtimex
#define SYS_acct __NR_acct
#define SYS_sched_setscheduler __NR_sched_setscheduler
#define SYS_mlockall __NR_mlockall
#define SYS_fstatfs __NR_fstatfs
#define SYS_stat __NR_stat
#define SYS_pciconfig_read __NR_pciconfig_read
#define SYS_sigpending __NR_sigpending
#define SYS_osf_old_lstat __NR_osf_old_lstat
#define SYS_osf_utc_gettime __NR_osf_utc_gettime
#define SYS_osf_getlogin __NR_osf_getlogin
#define SYS_chdir __NR_chdir
#define SYS_swapoff __NR_swapoff
#define SYS_semctl __NR_semctl
#define SYS_shmdt __NR_shmdt
#define SYS_syslog __NR_syslog
#define SYS_semget __NR_semget
#define SYS_osf_getmnt __NR_osf_getmnt
#define SYS_fchmod __NR_fchmod
#define SYS_osf_exportfs __NR_osf_exportfs
#define SYS_msgrcv __NR_msgrcv
#define SYS_readlink __NR_readlink
#define SYS_munlockall __NR_munlockall
#define SYS_osf_mremap __NR_osf_mremap
#define SYS_listen __NR_listen
#define SYS_accept __NR_accept
#define SYS_osf_table __NR_osf_table
#define SYS_osf_sstk __NR_osf_sstk
#define SYS_osf_getfh __NR_osf_getfh
#define SYS_sendto __NR_sendto
#define SYS_msgsnd __NR_msgsnd
#define SYS_sync __NR_sync
#define SYS_setitimer __NR_setitimer
#define SYS_fchown __NR_fchown
#define SYS_access __NR_access
#define SYS_sched_get_priority_max __NR_sched_get_priority_max
#define SYS_gettimeofday __NR_gettimeofday
#define SYS_mknod __NR_mknod
#define SYS_utimes __NR_utimes
#define SYS_osf_alt_plock __NR_osf_alt_plock
#define SYS_sched_get_priority_min __NR_sched_get_priority_min
#define SYS_getgroups __NR_getgroups
#define SYS_bind __NR_bind
#define SYS_osf_old_wait __NR_osf_old_wait
#define SYS_chmod __NR_chmod
#define SYS_mlock __NR_mlock
#define SYS_unlink __NR_unlink
#define SYS__sysctl __NR__sysctl
#define SYS_osf_getsysinfo __NR_osf_getsysinfo
#define SYS_osf_old_stat __NR_osf_old_stat
#define SYS_osf_old_creat __NR_osf_old_creat
#define SYS_osf_setlogin __NR_osf_setlogin
#define SYS_osf_revoke __NR_osf_revoke
#define SYS_lseek __NR_lseek
#define SYS_osf_uswitch __NR_osf_uswitch
#define SYS_osf_priocntlset __NR_osf_priocntlset
#define SYS_setpriority __NR_setpriority
#define SYS_pciconfig_write __NR_pciconfig_write
#define SYS_chown __NR_chown
#define SYS_exec_with_loader __NR_exec_with_loader
#define SYS_osf_utsname __NR_osf_utsname
#define SYS_osf_set_program_attributes __NR_osf_set_program_attributes
